import { aws_appsync, aws_iam } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { BaseApi, BaseApiProps } from './base-api';
import { LambdaFunction } from './func';
export interface GraphQlApiProps extends BaseApiProps {
    definitionFileName: string;
}
export interface VtlResolverOptions {
    /**
     * The datasource the VTL resolver targets
     */
    dataSource: aws_appsync.BaseDataSource;
    /**
     * string replacements to process on the VTL
     *
     * @default no variable expansions
     */
    variables?: {
        [name: string]: string;
    };
}
export interface JsResolverOptions {
    /**
     * Variables that will be put into the "stash" of the resolver pipeline
     *
     * @default none
     */
    readonly stashValues?: {
        [key: string]: string;
    };
    /**
     * name of the pipeline steps to create
     *
     * @default - only a default step will be created
     */
    readonly pipelineStepNames?: string[];
}
/**
 * The GraphQlApi construct sets up an AWS AppSync GraphQL API integrated with Cognito for authentication and DynamoDB for data storage.
 * This construct facilitates the creation of a GraphQL API with various configurations, including custom domain, logging, schema definition,
 * and authorization using Cognito User Pool and Identity Pool. It also provides methods to dynamically add resolvers and grant access to specific fields.
 *
 * @template RESOLVERS - The type definition for the GraphQL resolvers.
 *
 * @example
 * const api = new GraphQlApi(this, 'MyGraphQlApi', {
 *   apiName: 'MyAPI',
 *   stageName: 'dev',
 *   definitionFileName: 'schema.graphql',
 *   authentication: myCognitoAuth,
 *   singleTableDatastore: myDynamoDBTable,
 * });
 *
 * // Add a Lambda resolver
 * api.addLambdaResolver('Query', 'getItem');
 *
 * // Grant access to unauthenticated users for a specific query
 * api.grantAccessUnAuth('Query', 'getItem');
 */
export declare class GraphQlApi<RESOLVERS> extends BaseApi {
    private props;
    /**
     * The AWS AppSync GraphQL API instance.
     */
    readonly api: aws_appsync.GraphqlApi;
    /**
     * The optional DynamoDB data source for the GraphQL API.
     */
    readonly tableDataSource?: aws_appsync.DynamoDbDataSource;
    /**
     * A collection of Lambda functions used as resolvers for the GraphQL API.
     */
    private _functions;
    /**
     * The Cognito authentication configuration.
     */
    private cognitoAuth;
    /**
     * Creates an instance of GraphQlApi.
     *
     * @param scope - The scope in which this construct is defined.
     * @param id - The scoped construct ID.
     * @param props - The properties of the GraphQlApi construct.
     */
    constructor(scope: Construct, id: string, props: GraphQlApiProps);
    /**
     *
     */
    grantAccess<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(grantee: aws_iam.IGrantable, typeName: TYPE, ...fieldNames: (keyof FIELDTYPE)[]): void;
    /**
     *
     */
    grantAccessUnAuth<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, ...fieldNames: (keyof FIELDTYPE)[]): void;
    /**
     *
     */
    grantAccessAuth<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, ...fieldNames: (keyof FIELDTYPE)[]): void;
    /**
     * getFunctionForOperation
     */
    getFunctionForOperation<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, fieldName: keyof FIELDTYPE): LambdaFunction;
    addLambdaResolver<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, fieldName: keyof FIELDTYPE): LambdaFunction;
    addDynamoDbVtlResolver<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, fieldName: keyof FIELDTYPE, options?: Omit<VtlResolverOptions, 'dataSource'>): void;
    addDynamoDbJSResolver<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, fieldName: keyof FIELDTYPE, options?: JsResolverOptions): void;
    addJSResolver<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, fieldName: keyof FIELDTYPE, dataSource: aws_appsync.BaseDataSource, options?: JsResolverOptions): void;
    addVtlResolver<TYPE extends keyof RESOLVERS, FIELDTYPE extends NonNullable<RESOLVERS[TYPE]>>(typeName: TYPE, fieldName: keyof FIELDTYPE, options: VtlResolverOptions): void;
    private substVariables;
    private createEntryFile;
    private createJSResolverFile;
}
