import * as iam from 'aws-cdk-lib/aws-iam';
import * as sfn from 'aws-cdk-lib/aws-stepfunctions';
import * as constructs from 'constructs';
export interface WorkflowProps {
    readonly stateMachineType?: sfn.StateMachineType;
    readonly loggingConfiguration?: sfn.CfnStateMachine.LoggingConfigurationProperty;
    readonly tracingConfiguration?: sfn.CfnStateMachine.TracingConfigurationProperty;
    readonly definitionFileName: string;
    readonly definitionSubstitutions?: {
        [key: string]: (string);
    };
}
/**
 * The Workflow construct sets up an AWS Step Functions state machine with a specified definition file and IAM role.
 * This construct facilitates the creation of a Step Functions workflow, including the definition from an S3 location and
 * various configurations for logging and tracing. It implements the IGrantable interface for granting permissions.
 *
 * @example
 * const workflow = new Workflow(this, 'MyWorkflow', {
 *   definitionFileName: 'path/to/definition.asl.json',
 *   stateMachineType: sfn.StateMachineType.STANDARD,
 *   loggingConfiguration: {
 *     level: sfn.LogLevel.ALL,
 *     includeExecutionData: true,
 *     destinations: [new logs.LogGroup(this, 'LogGroup')],
 *   },
 *   tracingConfiguration: {
 *     enabled: true,
 *   },
 *   definitionSubstitutions: {
 *     '${MyVariable}': 'MyValue',
 *   },
 * });
 *
 * const lambdaFunction = new lambda.Function(this, 'MyFunction', {
 *   runtime: lambda.Runtime.NODEJS_20_X,
 *   handler: 'index.handler',
 *   code: lambda.Code.fromAsset('lambda'),
 * });
 *
 * workflow.grantPrincipal.grantInvoke(lambdaFunction);
 */
export declare class Workflow extends constructs.Construct implements iam.IGrantable {
    /**
     * The IAM role assumed by the state machine.
     */
    readonly role: iam.IRole;
    /**
     * The ARN of the created state machine.
     */
    readonly workflowArn: string;
    /**
     * The principal to which permissions can be granted.
     */
    readonly grantPrincipal: iam.IPrincipal;
    /**
     * Creates an instance of Workflow.
     *
     * @param scope - The scope in which this construct is defined.
     * @param id - The scoped construct ID.
     * @param props - The properties of the Workflow construct.
     */
    constructor(scope: constructs.Construct, id: string, props: WorkflowProps);
}
